Opcode

Struct Opcode 

#[non_exhaustive]
pub struct Opcode(pub u8);
An enum representing the gateway opcodes.

Discord docs.

Tuple Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
0: u8

Implementations

Source

impl Opcode

pub const Dispatch: Self

Dispatches an event.

pub const Heartbeat: Self

Used for ping checking.

pub const Identify: Self

Used for client handshake.

pub const PresenceUpdate: Self

Used to update the client status.

pub const VoiceStateUpdate: Self

Used to join/move/leave voice channels.

pub const VoiceServerPing: Self

Used for voice ping checking.

pub const Resume: Self

Used to resume a closed connection.

pub const Reconnect: Self

Used to tell clients to reconnect to the gateway.

pub const RequestGuildMembers: Self

Used to request guild members.

pub const InvalidSession: Self

Used to notify clients that they have an invalid session Id.

pub const Hello: Self

Sent immediately after connection, contains heartbeat + server info.

pub const HeartbeatAck: Self

Sent immediately following a client heartbeat that was received.

pub const RequestSoundboardSounds: Self

Used to request soundboard sounds from a list of guilds.

pub const fn Unknown(val: u8) -> Self

Variant value is unknown.

pub const fn as_str(&self) -> &'static str

Get a string representation