#[non_exhaustive]pub struct Opcode(pub u8);Expand description
An enum representing the gateway opcodes.
Tuple Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.0: u8Implementations
Sourceimpl Opcode
impl Opcode
Sourcepub const PresenceUpdate: Self
pub const PresenceUpdate: Self
Used to update the client status.
Sourcepub const VoiceStateUpdate: Self
pub const VoiceStateUpdate: Self
Used to join/move/leave voice channels.
Sourcepub const VoiceServerPing: Self
pub const VoiceServerPing: Self
Used for voice ping checking.
Sourcepub const RequestGuildMembers: Self
pub const RequestGuildMembers: Self
Used to request guild members.
Sourcepub const InvalidSession: Self
pub const InvalidSession: Self
Used to notify clients that they have an invalid session Id.
Sourcepub const HeartbeatAck: Self
pub const HeartbeatAck: Self
Sent immediately following a client heartbeat that was received.
Sourcepub const RequestSoundboardSounds: Self
pub const RequestSoundboardSounds: Self
Used to request soundboard sounds from a list of guilds.